@@ -1,12 +1,13 @@
 from math import exp, sqrt, e, cos, pi
-from flopt import Variable
+
+import flopt
 
 
 def create_objective(n):
     def obj(x):
         return (
             20
-            - 20 * (exp(-0.2 * sqrt(sum(xi * xi for xi in x)) / len(x)))
+            - 20 * (exp(-0.2 * sqrt(flopt.Sqnorm(x)) / len(x)))
             + e
             - exp(sum(cos(2 * pi * xi) for xi in x) / len(x))
         )
@@ -14,11 +15,8 @@ def create_objective(n):
     return obj
 
 
-def create_variables(n):
-    variables = [
-        Variable(name=f"x{i}", lowBound=-32.768, upBound=32.768, cat="Continuous")
-        for i in range(n)
-    ]
+def create_variables(n, cat="Continuous"):
+    variables = flopt.Variable.array("x", n, lowBound=-5.12, upBound=5.12, cat=cat)
     return variables
 
 
