@@ -1,6 +1,7 @@
-from flopt import Variable
 from math import sqrt
 
+import flopt
+
 
 def create_objective(*args, **kwargs):
     def obj(x):
@@ -10,10 +11,10 @@ def create_objective(*args, **kwargs):
     return obj
 
 
-def create_variables(*args, **kwargs):
+def create_variables(cat="Continuous", *args, **kwargs):
     variables = [
-        Variable(name=f"x1", lowBound=-15, upBound=-5, cat="Continuous"),
-        Variable(name=f"x2", lowBound=-3, upBound=3, cat="Continuous"),
+        flopt.Variable(name=f"x1", lowBound=-15, upBound=-5, cat=cat),
+        flopt.Variable(name=f"x2", lowBound=-3, upBound=3, cat=cat),
     ]
     return variables
 
