@@ -1,4 +1,4 @@
-from flopt import Variable
+import flopt
 
 
 def create_objective(*args, **kwargs):
@@ -9,10 +9,8 @@ def create_objective(*args, **kwargs):
     return obj
 
 
-def create_variables(*args, **kwargs):
-    variables = [
-        Variable(name=f"x{i}", lowBound=-5, upBound=5, cat="Continuous") for i in [0, 1]
-    ]
+def create_variables(cat="Continuous", *args, **kwargs):
+    variables = flopt.Variable.array("x", 2, lowBound=-5, upBound=5, cat=cat)
     return variables
 
 
