@@ -1,6 +1,7 @@
-from flopt import Variable
 from math import floor
 
+import flopt
+
 
 def create_objective(*args, **kwargs):
     def obj(x):
@@ -9,11 +10,8 @@ def create_objective(*args, **kwargs):
     return obj
 
 
-def create_variables(*args, **kwargs):
-    variables = [
-        Variable(name=f"x{i}", lowBound=-5.12, upBound=5.12, cat="Continuous")
-        for i in range(5)
-    ]
+def create_variables(cat="Continuous", *args, **kwargs):
+    variables = flopt.Variable.array("x", 5, lowBound=-5.12, upBound=5.12, cat=cat)
     return variables
 
 
