@@ -1,6 +1,7 @@
-from flopt import Variable
 from math import sin, sqrt
 
+import flopt
+
 
 def create_objective(*args, **kwargs):
     def obj(x):
@@ -12,11 +13,8 @@ def create_objective(*args, **kwargs):
     return obj
 
 
-def create_variables(*args, **kwargs):
-    variables = [
-        Variable(name=f"x{i}", lowBound=-512, upBound=512, cat="Continuous")
-        for i in [0, 1]
-    ]
+def create_variables(cat="Continuous", *args, **kwargs):
+    variables = flopt.Variable.array("x", 2, lowBound=-512, upBound=512, cat=cat)
     return variables
 
 
