@@ -1,6 +1,7 @@
-from flopt import Variable
 from math import sin, pi
 
+import flopt
+
 
 def create_objective(*args, **kwargs):
     def obj(x):
@@ -15,11 +16,8 @@ def create_objective(*args, **kwargs):
     return obj
 
 
-def create_variables(*args, **kwargs):
-    variables = [
-        Variable(name=f"x{i}", lowBound=-10, upBound=10, cat="Continuous")
-        for i in [0, 1]
-    ]
+def create_variables(cat="Continuous", *args, **kwargs):
+    variables = flopt.Variable.array(f"x", 2, lowBound=-10, upBound=10, cat=cat)
     return variables
 
 
