@@ -1,5 +1,6 @@
-from math import exp, sqrt, e, sin, cos, pi, sin
-from flopt import Variable
+from math import sin, pi, sin
+
+import flopt
 
 
 def create_objective(*args, **kwargs):
@@ -11,11 +12,8 @@ def create_objective(*args, **kwargs):
     return obj
 
 
-def create_variables(n):
-    variables = [
-        Variable(name=f"x{i}", lowBound=0, upBound=pi, cat="Continuous")
-        for i in range(2)
-    ]
+def create_variables(n, cat="Continuous"):
+    variables = flopt.Variable.array("x", 2, lowBound=0, upBound=pi, cat=cat)
     return variables
 
 
