@@ -1,5 +1,4 @@
-from math import exp, sqrt, e, cos, pi
-from flopt import Variable
+import flopt
 
 
 def create_objective(n):
@@ -14,11 +13,8 @@ def create_objective(n):
     return obj
 
 
-def create_variables(n):
-    variables = [
-        Variable(name=f"x{i}", lowBound=-5, upBound=5, cat="Continuous")
-        for i in range(n)
-    ]
+def create_variables(n, cat="Continuous"):
+    variables = flopt.Variable.array("x", n, lowBound=-5, upBound=5, cat=cat)
     return variables
 
 
