@@ -1,4 +1,4 @@
-from flopt import Variable
+import flopt
 
 
 def create_objective(n):
@@ -8,11 +8,8 @@ def create_objective(n):
     return obj
 
 
-def create_variables(n):
-    variables = [
-        Variable(name=f"x{i}", lowBound=-5.12, upBound=5.12, cat="Continuous")
-        for i in range(n)
-    ]
+def create_variables(n, cat="Continuous"):
+    variables = flopt.Variable.array("x", n, lowBound=-5.12, upBound=5.12, cat=cat)
     return variables
 
 
