@@ -1,5 +1,6 @@
-from math import exp, sqrt, e, sin, cos, pi
-from flopt import Variable
+from math import exp, sin, pi
+
+import flopt
 
 
 def create_objective(n):
@@ -11,11 +12,8 @@ def create_objective(n):
     return obj
 
 
-def create_variables(n):
-    variables = [
-        Variable(name=f"x{i}", lowBound=-2 * pi, upBound=2 * pi, cat="Continuous")
-        for i in range(n)
-    ]
+def create_variables(n, cat="Continuous"):
+    variables = flopt.Variable.array("x", n, lowBound=-2 * pi, upBound=2 * pi, cat=cat)
     return variables
 
 
