@@ -1,5 +1,6 @@
+import flopt
 from flopt.variable import VarElement
-from flopt.expression import Expression, Const
+from flopt.expression import Expression, Reduction, Const
 from flopt.constants import VariableType
 
 
@@ -76,11 +77,11 @@ def binarize(prob):
     """
     binarizes = dict()
     prob.obj = binarize_expression(prob.obj, binarizes)
-    for const in prob.constraints:
+    for const in prob.getConstraints():
         const.expression = binarize_expression(const.expression, binarizes)
 
     for source, binaries in binarizes.items():
-        prob += sum(binaries) == 1, f"for_bin_{source.name}_sum"
+        prob += flopt.Sum(binaries) == 1, f"for_bin_{source.name}_sum"
         prob += source == source.toBinary(), f"for_bin_{source.name}_eq"
 
     prob.resetVariables()
@@ -92,13 +93,16 @@ def binarize_expression(e, binarizes):
 
     Parameters
     ----------
-    e : Expresson or VarElement
+    e : Expression or Reduction or Const
     binarizes : dict
         binarizes[var] = binaries, where var = sum(i*var_bin)
     """
-    if isinstance(e, (VarElement, Const)):
+    assert isinstance(e, (Expression, Reduction, Const))
+    if isinstance(e, Const):
         return e
-    e = e.expand()
+    e = e.expand()  # convert reduction obj to Expression
+    e.resetlinkChildren()
+
     finish = False
     while not finish:
         finish = not binarize_traverse(e, binarizes)
@@ -110,7 +114,7 @@ def binarize_traverse(e, binarizes):
 
     Parameters
     ----------
-    e : Expresson or VarElement
+    e : Expression
     binarizes : dict
         binarizes[var] = binaries, where var = sum(i*var_bin)
 
