@@ -3,9 +3,9 @@ import numpy as np
 from flopt import Variable, Problem
 from flopt.variable import VariableArray
 from flopt.convert.linearize import linearize
-from flopt.constants import VariableType, np_float
+from flopt.constants import VariableType, ConstraintType, array_classes, np_float
 from flopt.error import ConversionError
-from flopt.env import setup_logger
+from flopt.env import setup_logger, create_variable_mode
 
 logger = setup_logger(__name__)
 
@@ -15,6 +15,13 @@ logger = setup_logger(__name__)
 # -------------------------------------------------------
 
 
+def to_nparray_or_None(x):
+    if x is not None:
+        if isinstance(x, array_classes) and not isinstance(x, np.ndarray):
+            x = np.array(x, dtype=np_float)
+    return x
+
+
 def merge(func, arrays):
     """
     Parameters
@@ -60,10 +67,10 @@ class QuadraticStructure:
     """
 
     def __init__(self, Q, c, C, x=None):
-        self.Q = np.array(Q, dtype=np_float)
-        self.c = np.array(c, dtype=np_float)
+        self.Q = to_nparray_or_None(Q)
+        self.c = to_nparray_or_None(c)
         self.C = C
-        self.x = np.array(x, dtype=object) if x is not None else None
+        self.x = to_nparray_or_None(x)
 
     def toLinear(self):
         """
@@ -92,9 +99,9 @@ class LinearStructure:
     """
 
     def __init__(self, c, C, x=None):
-        self.c = np.array(c, dtype=np_float)
+        self.c = to_nparray_or_None(c)
         self.C = C
-        self.x = np.array(x, dtype=object) if x is not None else None
+        self.x = to_nparray_or_None(x)
 
     def __repr__(self):
         return f"LinearStructure{self.c, self.C, self.x}"
@@ -130,17 +137,17 @@ class QpStructure:
         types="Continuous",
         x=None,
     ):
-        self.Q = np.array(Q, dtype=np_float)
-        self.c = np.array(c, dtype=np_float)
+        self.Q = to_nparray_or_None(Q)
+        self.c = to_nparray_or_None(c)
         self.C = C
-        self.G = np.array(G, dtype=np_float) if G is not None else None
-        self.h = np.array(h, dtype=np_float) if h is not None else None
-        self.A = np.array(A, dtype=np_float) if A is not None else None
-        self.b = np.array(b, dtype=np_float) if b is not None else None
-        self.lb = np.array(lb, dtype=np_float) if lb is not None else None
-        self.ub = np.array(ub, dtype=np_float) if ub is not None else None
+        self.G = to_nparray_or_None(G)
+        self.h = to_nparray_or_None(h)
+        self.A = to_nparray_or_None(A)
+        self.b = to_nparray_or_None(b)
+        self.lb = to_nparray_or_None(lb)
+        self.ub = to_nparray_or_None(ub)
         self.types = types
-        self.x = np.array(x, dtype=object) if x is not None else None
+        self.x = to_nparray_or_None(x)
 
     def numVariables(self):
         if self.x is not None:
@@ -165,7 +172,7 @@ class QpStructure:
         QpStructure
         """
         assert prob.obj.isQuadratic()
-        assert all(const.isLinear() for const in prob.constraints)
+        assert all(const.isLinear() for const in prob.getConstraints())
 
         if x is None:
             x = VariableArray(list(prob.getVariables()), dtype=object)
@@ -191,7 +198,9 @@ class QpStructure:
                 return x
 
         # create G, h
-        num_neq_consts = sum(const.type != "eq" for const in prob.constraints)
+        num_neq_consts = sum(
+            const.type() == ConstraintType.Le for const in prob.getConstraints()
+        )
         if num_neq_consts == 0:
             G = None
             h = None
@@ -199,23 +208,21 @@ class QpStructure:
             G = np.zeros((num_neq_consts, num_x), dtype=np_float)
             h = np.zeros((num_neq_consts,), dtype=np_float)
             i = 0
-            for const in iter_wrapper(prob.constraints, desc="convert neq constraints"):
-                if const.type == "le":
+            for const in iter_wrapper(
+                prob.getConstraints(), desc="convert neq constraints"
+            ):
+                if const.type() == ConstraintType.Le:
                     # c.T.dot(x) + C <= 0
                     linear = const.expression.toLinear(x)
                     G[i, :] = linear.c.T
                     h[i] = -linear.C
                     i += 1
-                elif const.type == "ge":
-                    # c.T.dot(x) + C >= 0
-                    linear = const.expression.toLinear(x)
-                    G[i, :] = -linear.c.T
-                    h[i] = linear.C
-                    i += 1
             assert i == num_neq_consts
 
         # create A, b
-        num_eq_consts = sum(const.type == "eq" for const in prob.constraints)
+        num_eq_consts = sum(
+            const.type() == ConstraintType.Eq for const in prob.getConstraints()
+        )
         if num_eq_consts == 0:
             A = None
             b = None
@@ -223,8 +230,10 @@ class QpStructure:
             A = np.zeros((num_eq_consts, num_x), dtype=np_float)
             b = np.zeros((num_eq_consts,), dtype=np_float)
             i = 0
-            for const in iter_wrapper(prob.constraints, desc="convert eq constraints"):
-                if const.type == "eq":
+            for const in iter_wrapper(
+                prob.getConstraints(), desc="convert eq constraints"
+            ):
+                if const.type() == ConstraintType.Eq:
                     linear = const.expression.toLinear(x)
                     A[i, :] = linear.c.T
                     b[i] = -linear.C
@@ -311,7 +320,8 @@ class QpStructure:
         else:
             types = self.types
         if self.x is not None:
-            s = Variable.array("__s", num_stack, lowBound=0, cat="Continuous")
+            with create_variable_mode():
+                s = Variable.array("slack", num_stack, lowBound=0, cat="Continuous")
             x = np.hstack([self.x, s])
         else:
             x = self.x
@@ -389,7 +399,7 @@ class QpStructure:
             prob = self.toFlopt()
             linearize(prob)
             if prob.obj.isLinear() and all(
-                const.isLinear() for const in prob.constraints
+                const.isLinear() for const in prob.getConstraints()
             ):
                 return LpStructure.fromFlopt(prob)
             else:
@@ -494,16 +504,16 @@ class LpStructure:
         types="Continuous",
         x=None,
     ):
-        self.c = np.array(c, dtype=np_float)
+        self.c = to_nparray_or_None(c)
         self.C = C
-        self.G = np.array(G, dtype=np_float) if G is not None else None
-        self.h = np.array(h, dtype=np_float) if h is not None else None
-        self.A = np.array(A, dtype=np_float) if A is not None else None
-        self.b = np.array(b, dtype=np_float) if b is not None else None
-        self.lb = np.array(lb, dtype=np_float) if lb is not None else None
-        self.ub = np.array(ub, dtype=np_float) if ub is not None else None
+        self.G = to_nparray_or_None(G)
+        self.h = to_nparray_or_None(h)
+        self.A = to_nparray_or_None(A)
+        self.b = to_nparray_or_None(b)
+        self.lb = to_nparray_or_None(lb)
+        self.ub = to_nparray_or_None(ub)
         self.types = types
-        self.x = np.array(x, dtype=object) if x is not None else None
+        self.x = to_nparray_or_None(x)
 
     def numVariables(self):
         if self.x is not None:
@@ -663,10 +673,10 @@ class IsingStructure:
     """
 
     def __init__(self, J, h, C, x=None):
-        self.J = np.array(J, dtype=np_float)
-        self.h = np.array(h, dtype=np_float)
+        self.J = to_nparray_or_None(J)
+        self.h = to_nparray_or_None(h)
         self.C = C
-        self.x = np.array(x, dtype=object) if x is not None else None
+        self.x = to_nparray_or_None(x)
 
     def numVariables(self):
         if self.x is not None:
@@ -769,9 +779,9 @@ class QuboStructure:
     """
 
     def __init__(self, Q, C, x=None):
-        self.Q = np.array(Q, dtype=np_float)
+        self.Q = to_nparray_or_None(Q)
         self.C = C
-        self.x = np.array(x, dtype=object) if x is not None else None
+        self.x = to_nparray_or_None(x)
 
     def numVariables(self):
         if self.x is not None:
