@@ -1,5 +1,6 @@
-from math import sqrt
+import math
 
+from flopt.constants import VariableType
 from flopt.env import setup_logger
 
 
@@ -31,16 +32,16 @@ class Solution:
     ----------
     Create a Solution which has Integer, Continuous and Binary Variables
 
-    >>> a = Variable(name='a', lowBound=0, upBound=1, cat='Integer')
-    >>> b = Variable(name='b', lowBound=1, upBound=2, cat='Continuous')
-    >>> c = Variable(name='c', cat='Binary')
-    >>> sol = Solution(name='abc', [a, b, c])
+    >>> a = Variable(name="a", lowBound=0, upBound=1, cat="Integer")
+    >>> b = Variable(name="b", lowBound=1, upBound=2, cat="Continuous")
+    >>> c = Variable(name="c", cat="Binary")
+    >>> sol = Solution("abc", [a, b, c])
 
     Four arithmetic operations are supported
     between Solutions or between a Solution and a constant.
 
-    >>> sol1 = Solution(name='sol1', [a, b])
-    >>> sol2 = Solution(name='sol2', [a, c])
+    >>> sol1 = Solution("sol1", [a, b])
+    >>> sol2 = Solution("sol2", [a, c])
     >>> sol_plus = sol1 + sol2  # (Solution + Solution or Solution + list)
     >>> sol_minus = sol1 - sol2  # (Solution - Solution or Solution - list)
     >>> sol_product = sol1 * 2  # (Solution * constant)
@@ -62,7 +63,7 @@ class Solution:
             value is VarElement family or Expression or Const
         """
         if self._var_dict is None:
-            self._var_dict = {variable.name: variable for variable in self._variables}
+            self._var_dict = {var.name: var for var in self._variables}
         return self._var_dict
 
     def value(self):
@@ -72,7 +73,7 @@ class Solution:
         list
             values of the variables in the Solution
         """
-        return [variable.value() for variable in self._variables]
+        return [var.value() for var in self._variables]
 
     def setValue(self, name, value):
         """
@@ -83,6 +84,17 @@ class Solution:
         """
         self.toDict()[name].setValue(value)
 
+    def setValuesFromArray(self, array):
+        """
+        Parameters
+        ----------
+        array: iterator
+            array of variable values
+        """
+        assert len(self._variables) == len(array)
+        for var, value in zip(self._variables, array):
+            var.setValue(value)
+
     def getVariables(self):
         """
         Returns
@@ -105,15 +117,16 @@ class Solution:
         """
         Copy the values of a Solution to itself (call by value)
         """
-        for vb, ovb in zip(self._variables, other._variables):
-            vb.setValue(ovb.value())
+        for var, ovar in zip(self._variables, other._variables):
+            var.setValue(ovar.value())
 
     def setRandom(self):
         """
         Set the solution values uniformly random
         """
-        for vb in self._variables:
-            vb.setRandom()
+        for var in self._variables:
+            var.setRandom()
+        return self
 
     def feasible(self):
         """
@@ -122,14 +135,14 @@ class Solution:
         bool
           Whether the solution is feasible or not
         """
-        return all(vb.feasible() for vb in self._variables)
+        return all(var.feasible() for var in self._variables)
 
     def clip(self):
         """
         Guarantee feasibility of the solution
         """
-        for vb in self._variables:
-            vb.clip()
+        for var in self._variables:
+            var.clip()
 
     def squaredNorm(self):
         """
@@ -138,7 +151,7 @@ class Solution:
         float
           Squared 2-norm of the solution as a vector in Euclid space
         """
-        return sum(vb.value() * vb.value() for vb in self._variables)
+        return sum(var.value() * var.value() for var in self._variables)
 
     def norm(self):
         """
@@ -147,7 +160,7 @@ class Solution:
         float
           2-norm of the solution as a vector in Euclid space
         """
-        return sqrt(self.squaredNorm())
+        return math.sqrt(self.squaredNorm())
 
     def dot(self, other):
         """
@@ -156,9 +169,10 @@ class Solution:
         float
           Inner product between the Solution and another Solution
         """
-        inner = 0
-        for vb1, vb2 in zip(self._variables, other._variables):
-            inner += vb1.value() * vb2.value()
+        inner = sum(
+            var1.value() * var2.value()
+            for var1, var2 in zip(self._variables, other._variables)
+        )
         return inner
 
     def __pos__(self):
@@ -281,6 +295,4 @@ class Solution:
         return self.__repr__()
 
     def __repr__(self):
-        return (
-            f'Solution({self.name}, [{", ".join([vb.name for vb in self._variables])}])'
-        )
+        return f"Solution({self.name}, [{', '.join([var.name for var in self._variables])}])"
