@@ -1,7 +1,16 @@
 import numpy as np
 
+from amplify import IsingPoly, gen_symbols, Solver, decode_solution
+from amplify.constraint import equal_to, greater_equal, less_equal
+from amplify.client import FixstarsClient
+
 from flopt.solvers.base import BaseSearch
-from flopt.constants import VariableType, SolverTerminateState
+from flopt.constants import (
+    VariableType,
+    ExpressionType,
+    ConstraintType,
+    SolverTerminateState,
+)
 from flopt.env import setup_logger
 
 
@@ -85,89 +94,57 @@ class AmplifySearch(BaseSearch):
         >>>   C 0, name None, 0.5*x_s+(0.5*y_s)+1.0 >= 0
     """
 
+    name = "AmplifySearch"
+    can_solve_problems = {
+        "Variable": VariableType.Spin,
+        "Objective": ExpressionType.Quadratic,
+        "Constraint": ExpressionType.Linear,
+    }
+
     def __init__(self):
         super().__init__()
-        self.name = "AmplifySearch"
         self.timelimit = 1
         self.token = None
-        self.can_solve_problems = ["ising"]
-
-    def available(self, prob, verbose=False):
-        """
-        Parameters
-        ----------
-        prob : Problem
-        verbose : bool
-
-        Returns
-        -------
-        bool
-            return true if it can solve the problem else false
-        """
-        for var in prob.getVariables():
-            if not var.type() == VariableType.Spin:
-                if verbose:
-                    logger.error(
-                        f"variable: \n{var}\n must be spin, but got {var.type()}"
-                    )
-                return False
-        if not prob.obj.isIsing():
-            if verbose:
-                logger.error(f"objective function: \n{prob.obj}\n must be ising form")
-            return False
-        for const in prob.constraints:
-            if not const.expression.isIsing():
-                if verbose:
-                    logger.error(f"constraint: \n{const}\n must be ising form")
-                return False
-        return True
-
-    def search(self):
-        from amplify import IsingPoly, gen_symbols, Solver, decode_solution
-        from amplify.constraint import equal_to, greater_equal, less_equal
-        from amplify.client import FixstarsClient
 
+    def search(self, solution, objective, constraints):
         assert (
             self.token is not None
         ), f'token is None, set token as .solve(..., token="xxx")'
 
+        self.start_build()
+
         x = self.prob.getVariables()
-        s = np.array(gen_symbols(IsingPoly, len(x)), dtype=object)
+        s = gen_symbols(IsingPoly, len(x))
+        np_s = np.array(gen_symbols(IsingPoly, len(x)), dtype=object)
 
         # objective function
-        ising = self.prob.obj.toIsing()
-        f = -s.T.dot(ising.J).dot(s) - ising.h.T.dot(s) + ising.C
+        ising = objective.toIsing()
+        f = -np_s.T.dot(ising.J).dot(np_s) - ising.h.T.dot(np_s) + ising.C
 
         # constraints
-        for const in self.prob.constraints:
+        for const in constraints:
             ising = const.expression.toIsing()
-            g = s.T.dot(ising.J).dot(s) - ising.h.T.dot(s) + ising.C
-            if const.type == "le":
-                f += less_equal(g, 0)
-            elif const.type == "ge":
-                f += greater_equal(g, 0)
-            else:
+            g = np_s.T.dot(ising.J).dot(np_s) - ising.h.T.dot(np_s) + ising.C
+            if const.type() == ConstraintType.Eq:
                 f += equal_to(g, 0)
+            else:  # ConstraintType.Le
+                f += less_equal(g, 0)
+
+        self.end_build()
 
         # solve
         client = FixstarsClient()  # Fixstars Optigan
-        client.parameters.timeout = int(1000.0 * self.timelimit)
+        client.parameters.timeout = int(1000.0 * (self.timelimit - self.build_time))
         client.token = self.token
 
         result = Solver(client).solve(f)
 
-        var_dict = {var.name: var for var in self.solution}
         for amplify_solution in list(result)[::-1]:
+            # fetch solution
             values = decode_solution(s, amplify_solution.values)
-            for var, value in zip(x, values):
-                self.solution.setValue(var.name, value.constant())
+            solution.setValuesFromArray(values)
 
-            # check whether update or not
-            obj_value = self.getObjValue(self.solution)
-            if obj_value < self.best_obj_value:
-                self.updateSolution(self.solution, obj_value)
-                self.recordLog()
-                if self.msg:
-                    self.during_solver_message("*")
+            # update best solution if needed
+            self.registerSolution(solution)
 
         return SolverTerminateState.Normal
