@@ -3,9 +3,13 @@ import pulp
 from flopt.solvers.base import BaseSearch
 from flopt.expression import Const
 from flopt.solution import Solution
+from flopt.constants import (
+    VariableType,
+    ExpressionType,
+    ConstraintType,
+    SolverTerminateState,
+)
 from flopt.env import setup_logger
-from flopt.constants import VariableType, SolverTerminateState
-
 
 logger = setup_logger(__name__)
 
@@ -23,7 +27,7 @@ class LpVariable(pulp.LpVariable):
 
 
 class PulpSearch(BaseSearch):
-    """PuLP API LP Solver
+    """API for PuLP, linear programming modeling tool
 
     Parameters
     ----------
@@ -31,83 +35,88 @@ class PulpSearch(BaseSearch):
         solver pulp use, see https://coin-or.github.io/pulp/technical/solvers.html.
         default is pulp.PULP_CBC_CMD
 
-    Returns
-    -------
-    status : int
-        status of solver
+    Examples
+    --------
+
+    .. code-block:: python
+
+        import flopt
+
+        # Variables
+        a = flopt.Variable("a", lowBound=0, upBound=1, cat="Integer")
+        b = flopt.Variable("b", lowBound=1, upBound=2, cat="Continuous")
+        c = flopt.Variable("c", lowBound=-1, upBound=3, cat="Continuous")
+
+        # Problem
+        prob = flopt.Problem()
+        prob += a + b + c + 2
+        prob += a + b >= 2
+        prob += b - c >= 3
+
+        solver = flopt.Solver("PulpSearch")
+        prob.solve(solver, msg=True)
+
+    When you use other solvers in pulp, for example GLPK solver, you set solver parameter in PulpSearch object.
+
+    .. code-block:: python
+
+        solver = flopt.Solver("PulpSearch")
+
+        import pulp
+        glpk_solver = pulp.GLPK_CMD()
+        solver.setParams(solver=glpk_solver)
+        prob.solve(solver, msg=True)
+
     """
 
+    name = "PulpSearch"
+    can_solve_problems = {
+        "Variable": VariableType.Number,
+        "Objective": ExpressionType.Linear,
+        "Constraint": ExpressionType.Linear,
+    }
+
     def __init__(self):
         super().__init__()
-        self.name = "PulpSearch"
         self.solver = None
-        self.can_solve_problems = ["lp"]
 
-    def available(self, prob, verbose=False):
-        """
-        Parameters
-        ----------
-        prob : Problem
-        verbose : bool
-
-        Returns
-        -------
-        bool
-            return true if objective and constraint functions are linear else false
-        """
-        for var in prob.getVariables():
-            if not var.type() in {
-                VariableType.Continuous,
-                VariableType.Integer,
-                VariableType.Binary,
-            }:
-                if verbose:
-                    logger.error(
-                        f"variable: \n{var}\n must be continouse, integer or binary, but got {var.type()}"
-                    )
-                return False
-        if not prob.obj.isLinear():
-            if verbose:
-                logger.error(f"objective function: \n{prob.obj}\n must be Linear")
-            return False
-        for const in prob.constraints:
-            if not const.expression.isLinear():
-                if verbose:
-                    logger.error(f"constraint: \n{const}\n must be Linear")
-                return False
-        return True
-
-    def search(self):
-
-        status = SolverTerminateState.Normal
-        lp_prob, lp_solution = self.createLpProblem(self.solution, self.prob)
+    def search(self, solution, *args):
+        self.start_build()
+        lp_prob, lp_solution = self.createLpProblem(solution, self.prob)
+        self.end_build()
 
         if self.solver is not None:
             solver = self.solver
         else:
-            solver = pulp.PULP_CBC_CMD(timeLimit=self.timelimit, msg=self.msg)
+            solver = pulp.PULP_CBC_CMD(
+                timeLimit=self.timelimit - self.build_time, msg=self.msg
+            )
+
         lp_status = lp_prob.solve(solver)
 
         # get result
-        for lp_var, var in zip(lp_solution, self.solution):
+        for lp_var in lp_solution:
+            name = lp_var.getName()
             value = lp_var.getValue()
-            if var.type() in {VariableType.Integer, VariableType.Binary}:
+            if lp_var.cat in {pulp.LpInteger, pulp.LpBinary}:
                 value = round(value)
-            var.setValue(value)
-        self.updateSolution(self.solution)
+            solution.setValue(name, value)
+
+        # update best solution if needed
+        self.registerSolution(solution)
 
         # lp_status =   -1: infeasible
         #               -2: unbounded
         #               -3: undefined
-        if lp_status == -1:
-            status = SolverTerminateState.Infeasible
-        elif lp_status == -2:
-            status = SolverTerminateState.Unbounded
-        else:
-            status = SolverTerminateState.Abnormal
         logger.info(f"PuLP LpStatus {pulp.constants.LpStatus[lp_status]}")
-
-        return status
+        if lp_status == -1:
+            return SolverTerminateState.Infeasible
+        elif lp_status == -2:
+            return SolverTerminateState.Unbounded
+        elif lp_status == -3:
+            return SolverTerminateState.Abnormal
+        else:
+            return SolverTerminateState.Normal
 
     def createLpProblem(self, solution, prob):
         """Convert Problem into pulp.LpProblem
@@ -133,24 +142,27 @@ class PulpSearch(BaseSearch):
             else:
                 raise ValueError(var.type())
             lp_var = LpVariable(
-                var.name, lowBound=var.lowBound, upBound=var.upBound, cat=cat
+                var.name, lowBound=var.getLb(), upBound=var.getUb(), cat=cat
             )
             lp_variables.append(lp_var)
         lp_solution = Solution("lp_solution", lp_variables)
 
         # conver Problem -> pulp.LpProblem
         name = "" if self.name is None else self.name
-        lp_prob = pulp.LpProblem(name=name)
+        sense = (
+            pulp.LpMinimize
+            if prob.sense in {"minimize", "Minimize"}
+            else pulp.LpMaximize
+        )
+        lp_prob = pulp.LpProblem(name=name, sense=sense)
         if not isinstance(prob.obj, Const):
             lp_prob.setObjective(prob.obj.value(lp_solution))
 
-        for const in prob.constraints:
+        for const in prob.getConstraints():
             const_exp = const.expression
-            if const.type == "eq":
+            if const.type() == ConstraintType.Eq:
                 lp_prob.addConstraint(const_exp.value(lp_solution) == 0, const.name)
-            elif const.type == "le":
+            else:  # const.type() == ConstraintType.Le
                 lp_prob.addConstraint(const_exp.value(lp_solution) <= 0, const.name)
-            elif const.type == "ge":
-                lp_prob.addConstraint(const_exp.value(lp_solution) >= 0, const.name)
 
         return lp_prob, lp_solution
