@@ -3,5 +3,5 @@ from .common import (
     start_solver_message,
     during_solver_message_header,
     during_solver_message,
-    end_solver_message
+    end_solver_message,
 )
