@@ -1,14 +1,29 @@
+import math
 import types
 import random
 import itertools
 
 import numpy as np
 
+import flopt
 from flopt.polynomial import Monomial, Polynomial
-from flopt.expression import Expression, Const
+from flopt.expression import ExpressionElement, Expression, Const
 from flopt.constraint import Constraint
-from flopt.constants import VariableType, number_classes, array_classes, np_float
-from flopt.env import setup_logger
+from flopt.constants import (
+    VariableType,
+    ConstraintType,
+    number_classes,
+    array_classes,
+    np_float,
+)
+from flopt.env import (
+    setup_logger,
+    create_variable_mode,
+    is_create_variable_mode,
+    get_variable_id,
+    get_variable_lower_bound,
+    get_variable_upper_bound,
+)
 
 
 logger = setup_logger(__name__)
@@ -27,18 +42,23 @@ class VariableArray(np.ndarray):
             shape = array.shape
         obj = super().__new__(cls, shape, dtype=VarElement)
         obj.mono_to_index = dict()
+        obj.set_mono = False
         return obj
 
-    def __init__(self, array, *args, **kwargs):
-        array = np.array(array)
+    def __init__(self, array, set_mono=True, *args, **kwargs):
+        array = np.array(array, dtype=object)
         for i in itertools.product(*map(range, self.shape)):
             self[i] = array[i]
-            self.mono_to_index[array[i].toMonomial()] = i
+            if set_mono:
+                self.mono_to_index[array[i].toMonomial()] = i
+        self.set_mono = set_mono
+        self.name = f"VariableArray({array})"
 
     def __array_finalize__(self, obj):
         self.mono_to_index = getattr(obj, "mono_to_index", None)
 
     def index(self, mono):
+        assert self.set_mono
         if not isinstance(mono, Monomial):
             mono = mono.toMonomial()
         i = self.mono_to_index[mono]
@@ -46,14 +66,11 @@ class VariableArray(np.ndarray):
             return i[0]
         return i
 
-    def sum_with_divide_and_conquer(self):
-        if self.size < 20 or self.shape[0] == 1:
-            return self.sum()
-        else:
-            mid = self.shape[0] // 2
-            return (self[:mid]).sum_with_divide_and_conquer() + (
-                self[mid:]
-            ).sum_with_divide_and_conquer()
+    def to_value(self, var_dict):
+        v = np.ndarray(self.shape)
+        for i in itertools.product(*map(range, self.shape)):
+            v[i] = var_dict[self[i].name].value()
+        return v
 
 
 # -------------------------------------------------------
@@ -61,9 +78,6 @@ class VariableArray(np.ndarray):
 # -------------------------------------------------------
 
 
-INI_BOUND = 1e20
-
-
 class VariableFactory:
     """API of variable generation"""
 
@@ -76,6 +90,12 @@ class VariableFactory:
         assert "^" not in name, f"The ^ character cannot be used in the name."
         assert "(" not in name, f"The ( character cannot be used in the name."
         assert ")" not in name, f"The ) character cannot be used in the name."
+        if is_create_variable_mode():
+            assert name.startswith("__"), f"The name must be started with __ characters"
+        else:
+            assert not name.startswith(
+                "__"
+            ), f"The name must not be started with __ characters"
 
     def __call__(
         self, name, lowBound=None, upBound=None, cat="Continuous", ini_value=None
@@ -123,22 +143,102 @@ class VariableFactory:
         >>> lowBound: 0
         >>> upBound : 10
         """
+        if is_create_variable_mode():
+            assert name is not None
+            name = f"__{get_variable_id()}_" + name
         self.checkName(name)
+        cat = str(cat)
         if cat == "Continuous":
             return VarContinuous(name, lowBound, upBound, ini_value)
         elif cat == "Integer":
             return VarInteger(name, lowBound, upBound, ini_value)
         elif cat == "Binary":
+            if lowBound is not None and lowBound != 0:
+                logger.warning(
+                    f"lowBound of {name} is ignored because its category is Binary"
+                )
+            if upBound is not None and upBound != 1:
+                logger.warning(
+                    f"upBound of {name} is ignored because its category is Binary"
+                )
             return VarBinary(name, ini_value)
         elif cat == "Spin":
             return VarSpin(name, ini_value)
         elif cat == "Permutation":
+            assert lowBound is not None and upBound is not None
             return VarPermutation(name, lowBound, upBound, ini_value)
         else:
             raise ValueError(f"cat {cat} cannot be used")
 
+    @classmethod
+    def dicts(
+        cls,
+        name,
+        indices=None,
+        lowBound=None,
+        upBound=None,
+        cat=VariableType.Continuous,
+        ini_value=None,
+        index_start=[],
+    ):
+        """
+        Parameters
+        ----------
+        name : str
+          name of variable
+        indices : tuple or generator
+            keys of variable dictionary
+        lowBound : float, optional
+          lowBound
+        upBound : float, optional
+          upBound
+        cat : str, optional
+          category of variable
+        ini_value : float, optional
+          set value to variable
+
+        Returns
+        -------
+        dict
+
+        """
+
+        if indices is None:
+            raise TypeError(
+                "LpVariable.dicts missing both 'indices' and deprecated 'indexs' arguments."
+            )
+
+        if isinstance(indices, types.GeneratorType):
+            indices = tuple(indices)
+        elif not isinstance(indices, tuple):
+            indices = (indices,)
+
+        index = indices[0]
+        indices = indices[1:]
+        variables = dict()
+        if len(indices) == 0:
+            for i in index:
+                if isinstance(i, array_classes):
+                    var_name = f"{name}_" + "_".join(map(str, i))
+                else:
+                    var_name = f"{name}_{i}"
+                variables[i] = Variable(
+                    var_name,
+                    lowBound,
+                    upBound,
+                    cat,
+                    ini_value,
+                )
+        else:
+            for i in index:
+                variables[i] = Variable.dicts(
+                    name, indices, lowBound, upBound, cat, ini_value, index_start + [i]
+                )
+        return variables
+
+    @classmethod
     def dict(
-        self, name, keys, lowBound=None, upBound=None, cat="Continuous", ini_value=None
+        cls, name, keys, lowBound=None, upBound=None, cat="Continuous", ini_value=None
     ):
         """
         Parameters
@@ -193,7 +293,7 @@ class VariableFactory:
                 var_name = f"{name}_" + "_".join(map(str, key))
             else:
                 var_name = f"{name}_{key}"
-            variables[key] = self(var_name, lowBound, upBound, cat, ini_value)
+            variables[key] = Variable(var_name, lowBound, upBound, cat, ini_value)
         return variables
 
     def array(
@@ -244,19 +344,23 @@ class VariableFactory:
             ini_value = np.array(ini_value, dtype=np_float)
         iterator = itertools.product(*map(range, shape))
         variables = np.ndarray(shape, dtype=object)
+        digits = [len(str(s)) for s in shape]
         for i in iterator:
-            var_name = f"{name}_" + "_".join(map(str, i))
+            var_name = f"{name}_" + "_".join(
+                str(s).zfill(digit) for s, digit in zip(i, digits)
+            )
             _lowBound = lowBound[i] if isinstance(lowBound, array_classes) else lowBound
             _upBound = upBound[i] if isinstance(upBound, array_classes) else upBound
             _cat = cat[i] if isinstance(cat, array_classes) else cat
             _ini_value = (
                 ini_value[i] if isinstance(ini_value, array_classes) else ini_value
             )
-            variables[i] = self(var_name, _lowBound, _upBound, _cat, _ini_value)
+            variables[i] = Variable(var_name, _lowBound, _upBound, _cat, _ini_value)
         return VariableArray(variables)
 
+    @classmethod
     def matrix(
-        self,
+        cls,
         name,
         n_row,
         n_col,
@@ -298,7 +402,7 @@ class VariableFactory:
         >>>         Variable(x_1_1, cat="Binary", ini_value=0)]], dtype=object)
 
         """
-        return self.array(name, (n_row, n_col), lowBound, upBound, cat, ini_value)
+        return Variable.array(name, (n_row, n_col), lowBound, upBound, cat, ini_value)
 
 
 # -------------------------------------------------------
@@ -309,13 +413,15 @@ class VariableFactory:
 class VarElement:
     """Base Variable class"""
 
-    def __init__(self, name, lowBound, upBound, ini_value):
+    def __init__(self, name, lowBound=None, upBound=None, ini_value=None):
         self.name = name
         self.lowBound = lowBound
         self.upBound = upBound
-        if ini_value is None:
-            ini_value = self.getIniValue()
-        self._value = ini_value
+        self._value = None
+        if ini_value is not None:
+            self._value = ini_value
+        else:
+            self.setRandom()
         self.monomial = Monomial({self: 1})
 
     def type(self):
@@ -327,26 +433,40 @@ class VarElement:
         """
         return self._type
 
-    def value(self, solution=None):
+    def value(self):
         """
         Returns
         -------
         float or int
           return value of variable
         """
-        if solution is None:
-            return self._value
-        else:
-            return solution.toDict()[self.name]
+        return self._value
 
     def setValue(self, value):
         self._value = value
 
-    def getLb(self):
-        return self.lowBound if self.lowBound is not None else -INI_BOUND
+    def getName(self):
+        return self.name
 
-    def getUb(self):
-        return self.upBound if self.upBound is not None else INI_BOUND
+    def getLb(self, must_number=False):
+        if must_number:
+            return (
+                self.lowBound
+                if self.lowBound is not None
+                else get_variable_lower_bound(to_int=True)
+            )
+        else:
+            return self.lowBound
+
+    def getUb(self, must_number=False):
+        if must_number:
+            return (
+                self.upBound
+                if self.upBound is not None
+                else get_variable_upper_bound(to_int=True)
+            )
+        else:
+            return self.upBound
 
     def feasible(self):
         """
@@ -355,7 +475,9 @@ class VarElement:
         bool
           return true if value of self is in between lowBound and upBound else false
         """
-        return self.getLb() <= self._value <= self.getUb()
+        return (
+            self.getLb(must_number=True) <= self._value <= self.getUb(must_number=True)
+        )
 
     def clip(self):
         """
@@ -363,16 +485,17 @@ class VarElement:
         ex. value < lowBound -> value = lowBound,
         value > upBound  -> value = upBound
         """
-        if self._value < self.getLb():
-            self._value = self.getLb()
-        elif self._value > self.getUb():
-            self._value = self.getUb()
+        if self.getLb() is not None:
+            lb = self.getLb(must_number=True)
+            self._value = max(self._value, lb)
+        if self.getUb() is not None:
+            ub = self.getUb(must_number=True)
+            self._value = min(self._value, ub)
 
     def toDict(self):
         return {self.name: self}
 
     def getVariables(self):
-        # for getVariables() in Expression class
         return {self}
 
     def isPolynomial(self):
@@ -397,6 +520,22 @@ class VarElement:
     def clone(self):
         raise NotImplementedError()
 
+    def max(self):
+        if self.upBound is not None:
+            return self.upBound
+        return get_variable_upper_bound()
+
+    def min(self):
+        if self.lowBound is not None:
+            return self.lowBound
+        return get_variable_lower_bound()
+
+    def traverse(self):
+        yield self
+
+    def traverseAncestors(self):
+        raise NotImplementedError
+
     def __add__(self, other):
         if isinstance(other, number_classes):
             if other == 0:
@@ -404,7 +543,7 @@ class VarElement:
             return Expression(self, Const(other), "+")
         elif isinstance(other, VarElement):
             return Expression(self, other, "+")
-        elif isinstance(other, Expression):
+        elif isinstance(other, ExpressionElement):
             if other.isNeg():
                 # self + (-other) --> self - other
                 return Expression(self, other.elmB, "-")
@@ -418,7 +557,7 @@ class VarElement:
             if other == 0:
                 return self
             return Expression(Const(other), self, "+")
-        elif isinstance(other, (VarElement, Expression)):
+        elif isinstance(other, (VarElement, ExpressionElement)):
             return Expression(other, self, "+")
         else:
             return NotImplemented
@@ -433,8 +572,8 @@ class VarElement:
                 return Expression(self, Const(other), "-")
         elif isinstance(other, VarElement):
             return Expression(self, other, "-")
-        elif isinstance(other, Expression):
-            if other.isNeg():
+        elif isinstance(other, ExpressionElement):
+            if other.isNeg() and isinstance(other, Expression):
                 # self - (-1*other) --> self + other
                 return Expression(self, other.elmB, "+")
             return Expression(self, other, "-")
@@ -445,10 +584,10 @@ class VarElement:
         if isinstance(other, number_classes):
             if other == 0:
                 # 0 - self --> -1 * self
-                return Expression(Const(-1), self, "*", name=f"-{self.name}")
+                return -self
             else:
                 return Expression(Const(other), self, "-")
-        elif isinstance(other, (VarElement, Expression)):
+        elif isinstance(other, (VarElement, ExpressionElement)):
             return Expression(other, self, "-")
         else:
             return NotImplemented
@@ -464,10 +603,13 @@ class VarElement:
             return Expression(Const(other), self, "*")
         elif isinstance(other, VarElement):
             return Expression(self, other, "*")
-        elif isinstance(other, Expression):
-            if other.operator == "*" and isinstance(other.elmA, Const):
-                # self * (a*other) -> a * (self * other)
-                return other.elmA * Expression(self, other.elmB, "*")
+        elif isinstance(other, ExpressionElement):
+            if isinstance(other, Expression):
+                if other.operator == "*" and isinstance(other.elmA, Const):
+                    # self * (a*other) -> a * (self * other)
+                    return other.elmA * Expression(self, other.elmB, "*")
+                else:
+                    return Expression(other, self, "*")
             else:
                 return Expression(other, self, "*")
         else:
@@ -482,12 +624,13 @@ class VarElement:
             elif other == -1:
                 return -self
             return Expression(Const(other), self, "*")
-        elif isinstance(other, VarElement):
-            return Expression(other, self, "*")
-        elif isinstance(other, Expression):
-            if other.operator == "*" and isinstance(other.elmA, Const):
-                # (a*other) * self -> a * (self * other)
-                return other.elmA * Expression(other.elmB, self, "*")
+        elif isinstance(other, ExpressionElement):
+            if isinstance(other, Expression):
+                if other.operator == "*" and isinstance(other.elmA, Const):
+                    # (a*other) * self -> a * (self * other)
+                    return other.elmA * Expression(other.elmB, self, "*")
+                else:
+                    return Expression(other, self, "*")
             else:
                 return Expression(other, self, "*")
         else:
@@ -500,7 +643,7 @@ class VarElement:
             elif other == -1:
                 return -self
             return Expression(self, Const(other), "/")
-        elif isinstance(other, (VarElement, Expression)):
+        elif isinstance(other, (VarElement, ExpressionElement)):
             return Expression(self, other, "/")
         else:
             return NotImplemented
@@ -510,7 +653,7 @@ class VarElement:
             if other == 0:
                 return Const(0)
             return Expression(Const(other), self, "/")
-        elif isinstance(other, (VarElement, Expression)):
+        elif isinstance(other, (VarElement, ExpressionElement)):
             return Expression(other, self, "/")
         else:
             return NotImplemented
@@ -518,7 +661,7 @@ class VarElement:
     def __mod__(self, other):
         if isinstance(other, int):
             return Expression(self, Const(other), "%")
-        elif isinstance(other, (VarInteger, Expression)):
+        elif isinstance(other, (VarInteger, ExpressionElement)):
             return Expression(self, other, "%")
         else:
             raise NotImplementedError()
@@ -530,7 +673,7 @@ class VarElement:
             elif other == 1:
                 return self
             return Expression(self, Const(other), "^")
-        elif isinstance(other, (VarElement, Expression)):
+        elif isinstance(other, (VarElement, ExpressionElement)):
             return Expression(self, other, "^")
         else:
             return NotImplemented
@@ -540,7 +683,7 @@ class VarElement:
             if other == 1:
                 return Const(1)
             return Expression(Const(other), self, "^")
-        elif isinstance(other, (VarElement, Expression)):
+        elif isinstance(other, (VarElement, ExpressionElement)):
             return Expression(other, self, "^")
         else:
             return NotImplemented
@@ -565,21 +708,30 @@ class VarElement:
         return hash(self.name)
 
     def __eq__(self, other):
-        return Constraint(Expression(self, Const(0), "+", name=self.name), other, "eq")
+        # self == other --> self - other == 0
+        if isinstance(other, (number_classes)) and other == 0:
+            return Constraint(
+                Expression(self, Const(0), "+", name=self.name) - other,
+                ConstraintType.Eq,
+            )
+        else:
+            return Constraint(self - other, ConstraintType.Eq)
 
     def __le__(self, other):
-        return Constraint(Expression(self, Const(0), "+", name=self.name), other, "le")
+        # self <= other --> self - other <= 0
+        if isinstance(other, (number_classes)) and other == 0:
+            return Constraint(
+                Expression(self, Const(0), "+", name=self.name), ConstraintType.Le
+            )
+        else:
+            return Constraint(self - other, ConstraintType.Le)
 
     def __ge__(self, other):
-        return Constraint(Expression(self, Const(0), "+", name=self.name), other, "ge")
+        # self >= other --> other - self <= 0
+        return Constraint(other - self, ConstraintType.Le)
 
     def __str__(self):
-        s = f"Name: {self.name}\n"
-        s += f"  Type    : {self._type}\n"
-        s += f"  Value   : {self.value()}\n"
-        s += f"  lowBound: {self.lowBound}\n"
-        s += f"  upBound : {self.upBound}"
-        return s
+        return self.name
 
     def __repr__(self):
         return f'VarElement("{self.name}", {self.lowBound}, {self.upBound}, {self.value()})'
@@ -588,35 +740,57 @@ class VarElement:
 class VarInteger(VarElement):
     """Integer Variable class"""
 
+    _type = VariableType.Integer
+
     def __init__(self, name, lowBound, upBound, ini_value):
+        lowBound = lowBound if lowBound is None else math.ceil(lowBound)
+        upBound = upBound if upBound is None else math.floor(upBound)
         super().__init__(name, lowBound, upBound, ini_value)
-        self._type = VariableType.Integer
         self.binarized = None
         self.binaries = set()
 
-    def value(self, solution=None):
+    def value(self):
         """
         Returns
         -------
         float or int
           return value of variable
         """
-        if solution is None:
-            return int(self._value)
-        else:
-            return solution.toDict()[self.name]
+        return round(self._value)
 
-    def getIniValue(self):
-        return (self.getLb() + self.getUb()) // 2
+    def getLb(self, must_number=False):
+        if must_number:
+            return (
+                self.lowBound
+                if self.lowBound is not None
+                else get_variable_lower_bound(to_int=True)
+            )
+        else:
+            return self.lowBound
+
+    def getUb(self, must_number=False):
+        if must_number:
+            return (
+                self.upBound
+                if self.upBound is not None
+                else get_variable_upper_bound(to_int=True)
+            )
+        else:
+            return self.upBound
 
     def setRandom(self):
-        self._value = random.randint(self.getLb(), self.getUb())
+        lb = self.getLb(must_number=True)
+        ub = self.getUb(must_number=True)
+        self._value = random.randint(lb, ub)
 
     def toBinary(self):
         if self.binarized is None:
             l, u = int(self.getLb()), int(self.getUb())
-            self.binaries = Variable.array(f"bin_{self.name}", u - l + 1, cat="Binary")
-            self.binarized = sum(
+            with create_variable_mode():
+                self.binaries = Variable.array(
+                    f"__bin_{self.name}", u - l + 1, cat="Binary"
+                )
+            self.binarized = flopt.Sum(
                 Const(i) * var_bin for i, var_bin in zip(range(l, u + 1), self.binaries)
             )
             if isinstance(self.binarized, VarElement):
@@ -634,6 +808,26 @@ class VarInteger(VarElement):
     def clone(self):
         return VarInteger(self.name, self.lowBound, self.upBound, self._value)
 
+    def __and__(self, other):
+        if isinstance(other, number_classes):
+            other = Const(other)
+        return Expression(self, other, "&")
+
+    def __rand__(self, other):
+        if isinstance(other, number_classes):
+            other = Const(other)
+        return Expression(other, self, "&")
+
+    def __or__(self, other):
+        if isinstance(other, number_classes):
+            other = Const(other)
+        return Expression(self, other, "|")
+
+    def __ror__(self, other):
+        if isinstance(other, number_classes):
+            other = Const(other)
+        return Expression(other, self, "|")
+
     def __repr__(self):
         return f'Variable("{self.name}", {self.lowBound}, {self.upBound}, "Integer", {self.value()})'
 
@@ -656,9 +850,10 @@ class VarBinary(VarInteger):
       >>> 0
     """
 
-    def __init__(self, name, ini_value, spin=None):
+    _type = VariableType.Binary
+
+    def __init__(self, name, ini_value=None, spin=None):
         super().__init__(name, 0, 1, ini_value)
-        self._type = VariableType.Binary
         self.spin = spin
 
     def setValue(self, value):
@@ -684,11 +879,12 @@ class VarBinary(VarInteger):
         {0, 1} to {-1, 1}
         """
         if self.spin is None:
-            self.spin = VarSpin(
-                f"{self.name}_s",
-                ini_value=int(2 * self._value - 1),
-                binary=self,
-            )
+            with create_variable_mode():
+                self.spin = VarSpin(
+                    f"{self.name}_s",
+                    ini_value=int(2 * self._value - 1),
+                    binary=self,
+                )
         return (self.spin + 1) * 0.5
 
     def clone(self):
@@ -698,7 +894,7 @@ class VarBinary(VarInteger):
         if id(other) == id(self):
             # a * a = a
             return self
-        elif isinstance(other, Expression) and other.operator == "*":
+        elif isinstance(other, ExpressionElement) and other.operator == "*":
             if id(other.elmA) == id(self) or id(other.elmB) == id(self):
                 # a * (a * b) = a * b
                 # a * (b * a) = b * a
@@ -715,26 +911,6 @@ class VarBinary(VarInteger):
         # 0 -> 1
         return Expression(Const(1), self, "-")
 
-    def __and__(self, other):
-        if isinstance(other, number_classes):
-            other = Const(other)
-        return Expression(self, other, "&")
-
-    def __rand__(self, other):
-        if isinstance(other, number_classes):
-            other = Const(other)
-        return Expression(other, self, "&")
-
-    def __or__(self, other):
-        if isinstance(other, number_classes):
-            other = Const(other)
-        return Expression(self, other, "|")
-
-    def __ror__(self, other):
-        if isinstance(other, number_classes):
-            other = Const(other)
-        return Expression(other, self, "|")
-
     def __repr__(self):
         return f'Variable("{self.name}", cat="Binary", ini_value={self.value()})'
 
@@ -742,9 +918,10 @@ class VarBinary(VarInteger):
 class VarSpin(VarElement):
     """Spin Variable class, which takes only 1 or -1"""
 
+    _type = VariableType.Spin
+
     def __init__(self, name, ini_value, binary=None):
         super().__init__(name, -1, 1, ini_value)
-        self._type = VariableType.Spin
         self.binary = binary
 
     def setValue(self, value):
@@ -761,16 +938,6 @@ class VarSpin(VarElement):
         """
         return self._value in {-1, 1}
 
-    def clip(self):
-        """map in an feasible area by clipping."""
-        if self._value <= 0:
-            self._value = self.lowBound
-        else:
-            self._value = self.upBound
-
-    def getIniValue(self):
-        return random.choice([-1, 1])
-
     def setRandom(self):
         """set random value to variable"""
         self._value = random.choice([-1, 1])
@@ -787,11 +954,12 @@ class VarSpin(VarElement):
         {-1, 1} to {0, 1}
         """
         if self.binary is None:
-            self.binary = VarBinary(
-                f"{self.name}_b",
-                ini_value=int((self._value + 1) / 2),
-                spin=self,
-            )
+            with create_variable_mode():
+                self.binary = VarBinary(
+                    f"{self.name}_b",
+                    ini_value=int((self._value + 1) / 2),
+                    spin=self,
+                )
         return 2 * self.binary - 1
 
     def toSpin(self):
@@ -803,7 +971,7 @@ class VarSpin(VarElement):
     def __mul__(self, other):
         if id(other) == id(self):
             return Const(1)
-        elif isinstance(other, Expression) and other.operator == "*":
+        elif isinstance(other, ExpressionElement) and other.operator == "*":
             if id(other.elmA) == id(self):
                 # a * (a * b) = b
                 if isinstance(other.elmB, number_classes):
@@ -821,7 +989,7 @@ class VarSpin(VarElement):
     def __rmul__(self, other):
         if id(other) == id(self):
             return Const(1)
-        elif isinstance(other, Expression) and other.operator == "*":
+        elif isinstance(other, ExpressionElement) and other.operator == "*":
             if id(other.elmA) == id(self):
                 # (a * b) * a = b
                 if isinstance(other.elmB, number_classes):
@@ -855,15 +1023,12 @@ class VarSpin(VarElement):
 class VarContinuous(VarElement):
     """Continuous Variable class"""
 
-    def __init__(self, name, lowBound, upBound, ini_value):
-        super().__init__(name, lowBound, upBound, ini_value)
-        self._type = VariableType.Continuous
-
-    def getIniValue(self):
-        return (self.getLb() + self.getUb()) / 2
+    _type = VariableType.Continuous
 
     def setRandom(self):
-        self._value = random.uniform(self.getLb(), self.getUb())
+        lb = self.getLb(must_number=True)
+        ub = self.getUb(must_number=True)
+        self._value = random.uniform(lb, ub)
 
     def clone(self):
         return VarContinuous(self.name, self.lowBound, self.upBound, self._value)
@@ -897,12 +1062,13 @@ class VarPermutation(VarElement):
     >>> [1, 2]
     """
 
-    def __init__(self, name, lowBound, upBound, ini_value):
-        super().__init__(name, lowBound, upBound, ini_value)
-        self._type = VariableType.Permutation
+    _type = VariableType.Permutation
 
-    def getIniValue(self):
-        return list(range(self.getLb(), self.getUb() + 1))
+    def __init__(self, name, lowBound=None, upBound=None, ini_value=None):
+        if ini_value is None:
+            ini_value = list(range(lowBound, upBound + 1))
+            random.shuffle(ini_value)
+        super().__init__(name, lowBound, upBound, ini_value)
 
     def value(self):
         """
