@@ -46,7 +46,7 @@ def prob_with_const():
 def prob_lp():
     a = flopt.Variable("a", cat="Continuous")
     b = flopt.Variable("b", cat="Continuous")
-    _prob = flopt.Problem("TestLp", sense="maximize")
+    _prob = flopt.Problem("TestLp", sense="Maximize")
     _prob += 1 * a + 3 * b <= 30
     _prob += 2 * a + 1 * b <= 40
     _prob += a >= 0
@@ -196,14 +196,26 @@ def test_OptunaCmaEsSearch_available(
     assert solver.available(prob_perm) == False
 
 
-def test_HyperoptTPESearch(prob, callback):
+def test_HyperoptTPESearch1(prob, callback):
     solver = Solver(algo="HyperoptTPESearch")
     solver.setParams(n_trial=10, callbacks=[callback])
     prob.solve(solver, timelimit=0.5)
 
 
+def test_HyperoptTPESearch2(prob_ising, callback):
+    solver = Solver(algo="HyperoptTPESearch")
+    solver.setParams(n_trial=10, callbacks=[callback])
+    prob_ising.solve(solver, timelimit=0.5)
+
+
 def test_HyperoptTPESearch_available(
-    prob, prob_with_const, prob_qp, prob_nonlinear, prob_perm
+    prob,
+    prob_with_const,
+    prob_qp,
+    prob_nonlinear,
+    prob_perm,
+    prob_ising,
+    prob_ising_const,
 ):
     solver = Solver(algo="HyperoptTPESearch")
     assert solver.available(prob) == True
@@ -211,6 +223,8 @@ def test_HyperoptTPESearch_available(
     assert solver.available(prob_qp) == False
     assert solver.available(prob_nonlinear) == False
     assert solver.available(prob_perm) == False
+    assert solver.available(prob_ising) == True
+    assert solver.available(prob_ising_const) == False
 
 
 def test_SFLA(prob, callback):
@@ -281,46 +295,30 @@ def test_ScipySearch1(prob_only_continuous, callback):
     prob_only_continuous.solve(solver, timelimit=0.5)
 
 
-def test_ScipySearch_available(
-    prob, prob_only_continuous, prob_with_const, prob_qp, prob_nonlinear, prob_perm
-):
+def test_ScipySearch2(prob_with_const, callback):
     solver = Solver(algo="ScipySearch")
-    assert solver.available(prob) == False
-    assert solver.available(prob_only_continuous) == True
-    assert solver.available(prob_with_const) == False
-    assert solver.available(prob_qp) == True
-    assert solver.available(prob_nonlinear) == False
-    assert solver.available(prob_perm) == False
-
-
-def test_ScipyLpSearch1(prob_only_continuous, callback):
-    solver = Solver(algo="ScipyLpSearch")
     solver.setParams(n_trial=10, callbacks=[callback])
-    prob_only_continuous.solve(solver, timelimit=0.5)
+    prob_with_const.solve(solver, timelimit=0.5)
 
 
-def test_ScipyLpSearch2(prob_lp, callback):
-    solver = Solver(algo="ScipyLpSearch")
-    solver.setParams(n_trial=10, callbacks=[callback])
-    prob_lp.solve(solver, timelimit=0.5)
-
-
-def test_ScipyLpSearch_available(
+def test_ScipySearch_available(
     prob,
     prob_only_continuous,
     prob_with_const,
-    prob_lp,
     prob_qp,
     prob_nonlinear,
+    prob_ising,
+    prob_ising_const,
     prob_perm,
 ):
-    solver = Solver(algo="ScipyLpSearch")
-    assert solver.available(prob) == False
+    solver = Solver(algo="ScipySearch")
+    assert solver.available(prob) == True
     assert solver.available(prob_only_continuous) == True
-    assert solver.available(prob_with_const) == False
-    assert solver.available(prob_lp) == True
-    assert solver.available(prob_qp) == False
-    assert solver.available(prob_nonlinear) == False
+    assert solver.available(prob_with_const) == True
+    assert solver.available(prob_qp) == True
+    assert solver.available(prob_nonlinear) == True
+    assert solver.available(prob_ising) == True
+    assert solver.available(prob_ising_const) == True
     assert solver.available(prob_perm) == False
 
 
@@ -429,16 +427,14 @@ def test_CvxoptQpSearch2(prob_qp, callback):
     prob_qp.solve(solver, timelimit=0.5)
 
 
-def test_ScipyLpSearch_available(
-    prob, prob_only_continuous, prob_with_const, prob_qp, prob_nonlinear, prob_perm
-):
-    solver = Solver(algo="ScipyLpSearch")
-    assert solver.available(prob) == False
-    assert solver.available(prob_only_continuous) == True
-    assert solver.available(prob_with_const) == False
-    assert solver.available(prob_qp) == False
-    assert solver.available(prob_nonlinear) == False
-    assert solver.available(prob_perm) == False
+def test_CvxoptQpSearch3(callback):
+    solver = Solver(algo="CvxoptQpSearch")
+    solver.setParams(n_trial=10, callbacks=[callback])
+
+    x = Variable("x", 1, 4, "Continuous")
+    prob_qp = Problem(name="issue72")
+    prob_qp += x * x
+    prob_qp.solve(solver)
 
 
 def test_AutoSearch1(prob, callback):
@@ -453,10 +449,10 @@ def test_AutoSearch2(prob_with_const, callback):
     prob_with_const.solve(solver, timelimit=0.5)
 
 
-# def test_AutoSearch3(prob_nonlinear, callback):
-#     solver = Solver(algo='auto')
-#     solver.setParams(n_trial=10, callbacks=[callback])
-#     prob_nonlinear.solve(solver, timelimit=0.5)
+def test_AutoSearch3(prob_ising, callback):
+    solver = Solver(algo="auto")
+    solver.setParams(n_trial=10, callbacks=[callback])
+    prob_ising.solve(solver, timelimit=0.5)
 
 
 def test_AutoSearch4(prob_with_const, callback):
@@ -465,6 +461,18 @@ def test_AutoSearch4(prob_with_const, callback):
     prob_with_const.solve(solver, timelimit=0.5)
 
 
+def test_AutoSearch5(prob_qp, callback):
+    solver = Solver(algo="auto")
+    solver.setParams(n_trial=10, callbacks=[callback])
+    prob_qp.solve(solver, timelimit=0.5)
+
+
+def test_AutoSearch6(prob_perm, callback):
+    solver = Solver(algo="auto")
+    solver.setParams(n_trial=10, callbacks=[callback])
+    prob_perm.solve(solver, timelimit=0.5)
+
+
 def test_AutoSearch_available(
     prob, prob_with_const, prob_qp, prob_nonlinear, prob_perm
 ):
@@ -472,14 +480,26 @@ def test_AutoSearch_available(
     assert solver.available(prob) == True
     assert solver.available(prob_with_const) == True
     assert solver.available(prob_qp) == True
-    assert solver.available(prob_nonlinear) == False
+    assert solver.available(prob_nonlinear) == True
     assert solver.available(prob_perm) == True
 
 
 def test_solver_log(prob, callback):
     solver = Solver(algo="RandomSearch")
     solver.setParams(n_trial=10, callbacks=[callback])
-    status, log = prob.solve(solver, timelimit=0.5)
+    status, log = prob.solve(solver, timelimit=0.2)
     print(log.getLog())
     print(log[0])
     fig, ax = log.plot(show=False)
+
+
+def test_solver_log_add(prob, callback):
+    solver = Solver(algo="RandomSearch")
+    solver.setParams(n_trial=10, callbacks=[callback])
+    status1, log1 = prob.solve(solver, timelimit=0.2)
+    status2, log2 = prob.solve(solver, timelimit=0.2)
+    add_len = len(log1 + log2)
+    assert add_len == len(log1) + len(log2)
+
+    log1 += log2
+    assert len(log1) == add_len
